@@ -1,7 +1,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-03-24 10:42:34
-:LastEditTime: 2021-01-12 08:37:36
+:LastEditTime: 2021-10-14 16:43:54
 :LastEditors: HuangJingCan
 :Description: StudioBaseHandler
 """
@@ -367,10 +367,34 @@ class StudioBaseHandler(BaseCookieHandler):
             self.redis_init().hdel(config.get_value("redis_provider_name_user_login"), user_id)
         else:
             UserLoginModel(config.get_value("manage_context_key")).del_entity("UserID=%s", user_id)
+
         self.clear_cookie("UserID")
         self.clear_cookie("UserIDMD5")
         self.clear_cookie("UserToken")
 
+    def login_cookie(self, user_login):
+        """
+        :description: 登录状态设置
+        :param user_login: 登录信息
+        :return: user_login
+        :last_editors: HuangJingCan
+        """
+        if config.get_value("login_type") == "redis":
+            self.redis_init().hset(config.get_value("redis_provider_name_user_login"), user_login.UserID, self.json_dumps(user_login))
+        else:
+            user_login_base = UserLoginModel(config.get_value("base_manage_context_key"))
+            user_login_base.add_update_entity(user_login, "UserIDMD5=%s,ExpireTime=%s,UserToken=%s", [user_login.UserIDMD5, user_login.ExpireTime, user_login.UserToken])
+
+        cookie_domain = config.get_value("cookie_domain")
+        if cookie_domain:
+            self.set_cookie("UserID", user_login.UserID, domain=cookie_domain)
+            self.set_cookie("UserIDMD5", user_login.UserIDMD5, domain=cookie_domain)
+            self.set_cookie("UserToken", user_login.UserToken, domain=cookie_domain)
+        else:
+            self.set_cookie("UserID", user_login.UserID)
+            self.set_cookie("UserIDMD5", user_login.UserIDMD5)
+            self.set_cookie("UserToken", user_login.UserToken)
+
     def check_power_menu(self, api_path, cote_id):
         """
         :description: 权限判断
@@ -498,7 +522,7 @@ def power_filter(is_check_power=True, optional_params=None):
             base_user_info = self.get_base_user_info()
             if user_info and base_user_info:
                 if is_check_power and user_info.IsSuper != 1 and base_user_info.IsSuper != 1:
-                    api_path = self.request.uri
+                    api_path = self.request.path
                     if api_path.strip() == "":
                         return self.reponse_common("NoPower", "没有权限")
                     page_id = self.request_manage_page_id()
