@@ -2,8 +2,8 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-29 11:00:52
-:LastEditTime: 2021-06-25 11:43:58
-:LastEditors: ChenXiaolei
+:LastEditTime: 2021-07-02 14:31:38
+:LastEditors: HuangJingCan
 :Description: 文件上传信息
 """
 from PIL import Image
@@ -32,7 +32,6 @@ class FileUpload():
     :return: 
     :last_editors: HuangJingCan
     """
-
     def __init__(self, file_context_key='db_sevenstudio'):
         self.file_context_key = file_context_key
 
@@ -54,9 +53,7 @@ class FileUpload():
 
         storage_config = ""
         file_restrict_model = FileRestrictModel(self.file_context_key)
-        file_restrict = file_restrict_model.get_entity(
-            "ResourceCode=%s AND RestrictCode=%s",
-            params=[resource_code, restrict_code])
+        file_restrict = file_restrict_model.get_entity("ResourceCode=%s AND RestrictCode=%s", params=[resource_code, restrict_code])
         if not file_restrict:
             invoke_result.ResultCode = "NoExistFileRestrict"
             invoke_result.ResultMessage = "文件配置不存在"
@@ -72,24 +69,13 @@ class FileUpload():
             file_name = info["filename"]
             file_body = info["body"]
 
-            invoke_result = self.upload_file(file_body, file_name,
-                                             file_restrict)
+            invoke_result = self.upload_file(file_body, file_name, file_restrict)
             if invoke_result.ResultCode == "0" and invoke_result.Data:
                 invoke_result.Data = invoke_result.Data.ResourcePath
 
         return invoke_result
 
-    def upload_file(self,
-                    stream,
-                    file_name,
-                    file_restrict,
-                    image_width=0,
-                    image_height=0,
-                    quality=0,
-                    is_format_jpeg=0,
-                    is_water_mark=0,
-                    horizontal_align=0,
-                    vertical_align=0):
+    def upload_file(self, stream, file_name, file_restrict, image_width=0, image_height=0, quality=0, is_format_jpeg=0, is_water_mark=0, horizontal_align=0, vertical_align=0):
         """
         :description: 文件上传
         :param {type} 
@@ -100,8 +86,7 @@ class FileUpload():
         file_upload_info = FileUploadInfo()
         file_extension = os.path.splitext(file_name)[1]
         if file_restrict.FileExtension != "":
-            file_find = file_restrict.FileExtension.find(
-                file_extension.strip("."))
+            file_find = file_restrict.FileExtension.find(file_extension.strip("."))
             if file_find == -1:
                 invoke_result.ResultCode = "1"
                 invoke_result.ResultMessage = f"上传的文件扩展名必须是{file_restrict.FileExtension}，当前文件是:{file_extension}"
@@ -115,11 +100,7 @@ class FileUpload():
         if file_extension.__contains__(".gif"):
             return self.switch_upload(stream, file_name, file_restrict)
 
-        if image_width > 0 or image_height > 0 or (
-                file_extension.__contains__(".bmp")
-                or file_extension.__contains__(".png")
-        ) and is_format_jpeg or is_water_mark or (quality > 0
-                                                  and quality < 100):
+        if image_width > 0 or image_height > 0 or (file_extension.__contains__(".bmp") or file_extension.__contains__(".png")) and is_format_jpeg or is_water_mark or (quality > 0 and quality < 100):
             # 其他图片格式转jpg
             # im = Image.open(BytesIO(stream))
             # im = im.convert("RGB")
@@ -168,8 +149,7 @@ class FileUpload():
                 query_size = f"?w={image_width}&h={image_height}"
 
         file_storage_path_model = FileStoragePathModel(self.file_context_key)
-        file_storage_path = file_storage_path_model.get_entity_by_id(
-            file_restrict.FileStoragePathID)
+        file_storage_path = file_storage_path_model.get_entity_by_id(file_restrict.FileStoragePathID)
         if file_storage_path.StorageTypeID == 1:
             # 本地文件
             resource_code = file_restrict.ResourceCode
@@ -177,22 +157,13 @@ class FileUpload():
             resource_ver_id = UUIDHelper.get_uuid()
 
             resource_uuid_file_name = resource_ver_id + file_extension
-            virtual_name = RandomUtil.get_random_switch_string(
-                file_storage_path.VirtualName)
-            path_format_value = self.get_resource_path_format_value(
-                create_date_time, resource_ver_id,
-                file_restrict.PathFormatCodeType)
-            resource_url = self.get_resource_url(
-                virtual_name, file_restrict.AccessModeCodeType, resource_code,
-                path_format_value, resource_uuid_file_name, file_name)
-            full_file_name = self.get_resource_full_file_name_path(
-                file_storage_path.StoragePath,
-                file_restrict.AccessModeCodeType, resource_code,
-                path_format_value, resource_uuid_file_name, file_name)
+            virtual_name = RandomUtil.get_random_switch_string(file_storage_path.VirtualName)
+            path_format_value = self.get_resource_path_format_value(create_date_time, resource_ver_id, file_restrict.PathFormatCodeType)
+            resource_url = self.get_resource_url(virtual_name, file_restrict.AccessModeCodeType, resource_code, path_format_value, resource_uuid_file_name, file_name)
+            full_file_name = self.get_resource_full_file_name_path(file_storage_path.StoragePath, file_restrict.AccessModeCodeType, resource_code, path_format_value, resource_uuid_file_name, file_name)
 
             if file_restrict.IsMd5 == 1:
-                file_upload_info.Md5Value = CryptoHelper.md5_encrypt_bytes(
-                    stream).upper()
+                file_upload_info.Md5Value = CryptoHelper.md5_encrypt_bytes(stream).upper()
 
             im = Image.open(BytesIO(stream))
             im.save(full_file_name)
@@ -211,34 +182,27 @@ class FileUpload():
         elif file_storage_path.StorageTypeID in (4, 5, 6, 7):
             if file_storage_path.StorageTypeID == 4:
                 # 金山云
-                invoke_result = KS3.upload(file_storage_path.StorageConfig,
-                                           file_name, stream)
+                invoke_result = KS3.upload(file_storage_path.StorageConfig, file_name, stream)
             elif file_storage_path.StorageTypeID == 5:
-                # 金山云
-                invoke_result = KS3.upload(file_storage_path.StorageConfig,
-                                           file_name, stream)
+                # 阿里云
+                invoke_result = OSS2.upload(file_storage_path.StorageConfig, file_name, stream)
             elif file_storage_path.StorageTypeID == 6:
                 # 腾讯云
-                invoke_result = COS.upload(file_storage_path.StorageConfig,
-                                           file_name, stream)
+                invoke_result = COS.upload(file_storage_path.StorageConfig, file_name, stream)
             elif file_storage_path.StorageTypeID == 7:
                 # 百度云
-                invoke_result = BOS.upload(file_storage_path.StorageConfig,
-                                           file_name, stream)
+                invoke_result = BOS.upload(file_storage_path.StorageConfig, file_name, stream)
 
             if invoke_result.ResultCode != "0":
                 return invoke_result
 
             if invoke_result.Data:
                 file_upload_info.Md5Value = invoke_result.Data["Md5Value"]
-                file_upload_info.ResourcePath = invoke_result.Data[
-                    "ResourcePath"]
-                file_upload_info.OriginalName = invoke_result.Data[
-                    "OriginalName"]
+                file_upload_info.ResourcePath = invoke_result.Data["ResourcePath"]
+                file_upload_info.OriginalName = invoke_result.Data["OriginalName"]
                 file_upload_info.FilePath = invoke_result.Data["FilePath"]
                 file_upload_info.ImageWidth = invoke_result.Data["ImageWidth"]
-                file_upload_info.ImageHeight = invoke_result.Data[
-                    "ImageHeight"]
+                file_upload_info.ImageHeight = invoke_result.Data["ImageHeight"]
 
         if file_restrict.IsHistory == 1:
             file_history = FileHistory()
@@ -263,8 +227,7 @@ class FileUpload():
 
         return invoke_result
 
-    def get_resource_path_format_value(self, create_date_time, resource_ver_id,
-                                       path_format_code_id):
+    def get_resource_path_format_value(self, create_date_time, resource_ver_id, path_format_code_id):
         """
         :description: 获取附件路径格式值规则
         :param {type} 
@@ -273,18 +236,14 @@ class FileUpload():
         """
         result = ""
         if path_format_code_id == 0:
-            result = TimeHelper.datetime_to_format_time(
-                create_date_time, "%Y-%m-%d")
+            result = TimeHelper.datetime_to_format_time(create_date_time, "%Y-%m-%d")
         elif path_format_code_id == 1:
-            result = TimeHelper.datetime_to_format_time(
-                create_date_time, "%Y-%m-%d-%H")
+            result = TimeHelper.datetime_to_format_time(create_date_time, "%Y-%m-%d-%H")
         elif path_format_code_id == 2:
             result = str(resource_ver_id)
         return result
 
-    def get_resource_url(self, virtual_name, access_mode_code_value,
-                         resource_code, path_format_value,
-                         resource_uuid_file_name, resource_file_name):
+    def get_resource_url(self, virtual_name, access_mode_code_value, resource_code, path_format_value, resource_uuid_file_name, resource_file_name):
         """
         :description: 获取资源网址规则 [组合附件网址]
         :param {type} 
@@ -306,14 +265,7 @@ class FileUpload():
         resource_url = f"{virtual_name}/{resource_code}/{uuid_file_name}/{resource_file_name}"
         return resource_url
 
-    def get_resource_full_file_name_path(self,
-                                         storage_path,
-                                         access_mode_code_value,
-                                         resource_code,
-                                         path_format_value,
-                                         resource_uuid_file_name,
-                                         resource_file_name,
-                                         is_create_directory=True):
+    def get_resource_full_file_name_path(self, storage_path, access_mode_code_value, resource_code, path_format_value, resource_uuid_file_name, resource_file_name, is_create_directory=True):
         """
         :description: 获取附件完整文件名规则 [组合完整文件名]
         :param {type} 
@@ -322,13 +274,9 @@ class FileUpload():
         """
         resource_directory = ""
         if storage_path == "":
-            resource_directory = self.get_resource_directory_path(
-                access_mode_code_value, resource_code, path_format_value,
-                resource_uuid_file_name)
+            resource_directory = self.get_resource_directory_path(access_mode_code_value, resource_code, path_format_value, resource_uuid_file_name)
         else:
-            dir_path = self.get_resource_directory_path(
-                access_mode_code_value, resource_code, path_format_value,
-                resource_uuid_file_name)
+            dir_path = self.get_resource_directory_path(access_mode_code_value, resource_code, path_format_value, resource_uuid_file_name)
             resource_directory = os.path.join(storage_path, dir_path)
         if is_create_directory:
             if not os.path.exists(resource_directory):
@@ -337,9 +285,7 @@ class FileUpload():
             return resource_directory + "\\" + resource_file_name
         return resource_directory + "\\" + resource_uuid_file_name
 
-    def get_resource_directory_path(self, access_mode_code_value,
-                                    resource_code, path_format_value,
-                                    resource_uuid_file_name):
+    def get_resource_directory_path(self, access_mode_code_value, resource_code, path_format_value, resource_uuid_file_name):
         """
         :description: 获取资源目录规则
         :param {type} 
@@ -352,8 +298,6 @@ class FileUpload():
         else:
             resource_directory = resource_code
         if access_mode_code_value == AccessModeCodeType.VirtualOriginalAccess.value:
-            resource_directory = os.path.join(
-                resource_directory,
-                os.path.splitext(resource_uuid_file_name)[0])
+            resource_directory = os.path.join(resource_directory, os.path.splitext(resource_uuid_file_name)[0])
 
         return resource_directory
